.. SayTeX documentation master file, created by
   sphinx-quickstart on Sun May  5 18:03:18 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Overview
==================================


SayTeX
-----------------------

SayTeX can convert natural language math expressions into valid LaTeX.

The SayTeX project consists of one main product: the ``saytex`` Python package,
which provides a simple interface for converting natural language into LaTeX.

The SayTeX website is at `<https://saytex.xyz>`_ and all code is hosted
on GitHub: `<https://github.com/arvid220u/saytex>`_.

Documentation Index
----------------------

.. toctree::
   :maxdepth: 2

   self
   gettingstarted
   philosophy
   advancedusage
   saytexsyntax
   developing
   Package Reference <saytex>
